@@ -94,7 +94,7 @@ def init_tpl_response(action='', title=''):
     '''Create a dictionary with the minimal info needed to render a template
     '''
     return {
-        'get_url': app.get_url,
+        'get_url': get_url,
         'alerts': alerts,
         'help_page': config.get('abow.help_page'),
         'lang': l10n.get_lang(),
